@@ -13,7 +13,7 @@ class GalleryPublishedManager(models.Manager):
         return super(GalleryPublishedManager, self).get_query_set().filter(publish=True)
 
 
-#class AlbumPublishedManager(models.Manager):
-    #"""Manager for Album model"""
-    #def get_query_set(self):
-        #return super(AlbumPublishedManager, self).get_query_set().filter(publish=True)
+class AlbumPublishedManager(models.Manager):
+    """Manager for Album model"""
+    def get_query_set(self):
+        return super(AlbumPublishedManager, self).get_query_set().filter(publish=True)
